@@ -185,7 +185,7 @@ class FloatingPointFilter:
         self.origFileName = origFileName
         self.tolerance = tolerance if tolerance else None
         self.relative = relative if relative else None
-        self.split = split if split else None
+        self.split = split
 
     def filterFile(self, inFile, writeFile):
         fromlines = open(self.origFileName, errors="ignore").readlines()
@@ -465,6 +465,7 @@ class LineFilter:
         return self.linesToRemove > 1 or self.prevLinesToRemove > 0 or self.untrigger is not None
 
     def applyTo(self, line, lineNumber=0, alreadyFilteredAway=False):
+        self.diag.info("Filtering " + repr(line.rstrip()))
         if self.autoRemove:
             return self.applyAutoRemove(line)
         elif alreadyFilteredAway and not self.isMultiLine():
@@ -474,6 +475,7 @@ class LineFilter:
             self.diag.info(repr(self.trigger) + " matched " + line.rstrip())
             return self.applyMatchingTrigger(line)
         else:
+            self.diag.info(repr(self.trigger) + " did not match " + line.rstrip())
             return False, line, 0
 
     def applyAutoRemove(self, line):
